@@ -5,7 +5,7 @@
 ;;   Copyright (C) 2002,2003,2004,2005 Kiyoka Nishyama
 ;;   This program was derived fr yc.el-4.0.13(auther: knak)
 ;;
-;;     $Date: 2005/04/29 10:21:27 $
+;;     $Date: 2005/05/28 06:21:55 $
 ;;
 ;; This file is part of Sumibi
 ;;
@@ -27,13 +27,13 @@
 ;;;     $BG[I[>r7o(B: GPL
 ;;; $B:G?7HGG[I[85(B: http://sourceforge.jp/projects/sumibi/
 
-;;; $BK\%P!<%8%g%s(B 0.2.0 $B$O0BDjHG$G$9!#(B
-;;; $BF0:n$O0BDj$7$F$$$k$H$O;W$$$^$9$,5!G=E*$K$O$^$@$^$@ITB-$7$F$$$^$9!#8fN;>5$/$@$5$$!#(B
-;;; $BITL@$JE@$d2~A1$7$?$$E@$,$"$l$P(BSumibi$B$N%a!<%j%s%0%j%9%H$K;22C$7$F(B
-;;; $B%U%#!<%I%P%C%/$r$*$M$,$$$7$^$9!#(B
+;;; $BK\%P!<%8%g%s(B 0.3.0 $B$O%F%9%HHG$G$9!#(B
+;;; $B%P!<%8%g%s7ONs(B 0.3.x $B$G$O$I$s$I$s5!G=DI2C$r9T$J$&$?$aF0:n$,0BDj$7$F$$$J$$2DG=@-$,$"$j$^$9!#(B
+;;; $B0BDj;X8~$NJ}$O(B $B0BDjHG(B (0.2.x) $B$r$4;HMQ$/$@$5$$!#(B
+;;; $BITL@$JE@$d2~A1$7$?$$E@$,$"$l$P(BSumibi$B$N%a!<%j%s%0%j%9%H$K;22C$7$F%U%#!<%I%P%C%/$r$*$M$,$$$7$^$9!#(B
 ;;;
-;;; $B$^$?!"(BSumibi$B$K6=L#$r;}$C$F$$$?$@$$$?J}$O$"$J$?$,%W%m%0%i%^$+$I$&$+$K$+$+$o$i$:!"(B
-;;; $B5$7Z$K%W%m%8%'%/%H$K;22C$7$F$/$@$5$$!#(B
+;;; $B$^$?!"(BSumibi$B$K6=L#$r;}$C$F$$$?$@$$$?J}$O$I$J$?$G$b(B
+;;; $B5$7Z$K%W%m%8%'%/%H$K$4;22C$/$@$5$$!#(B
 ;;;
 ;;; $BK\%P!<%8%g%s$K$O<!$N$h$&$J@)8B$,$"$j$^$9!#(B
 ;;;   1. $BK\%Q%C%1!<%8$K$O(BEmacs$BMQ$N%/%i%$%"%s%H$N$_4^$^$l$F$$$^$9!#(B
@@ -41,7 +41,6 @@
 ;;;      2) SSL$B>ZL@=q$r;HMQ$7!":GDc8B$N%;%-%e%j%F%#!<$O3NJ]$7$F$$$^$9!#(B 
 ;;;         SSL$B>ZL@=q$O(B CAcert( http://www.cacert.org/ )$B$N$b$N$r;H$C$F$$$^$9!#(B
 ;;;      3) $B>-Mh(BSumibi Server$B$N%W%m%H%3%k$OJQ99$K$J$j$^$9!#(B
-;;;      4) Sumibi Server$BB&$N%=!<%9%3!<%I$b(BGPL$B$G$9!#(Bsourceforge.jp$B$N(BCVS$B$G8x3+$5$l$F$$$^$9!#(B
 ;;;
 ;;;   2. $B%P%0$,$^$@$^$@$"$j$^$9!#(B^_^;
 ;;;
@@ -63,16 +62,11 @@
   :group 'input-method
   :group 'Japanese)
 
-(defcustom sumibi-server-url "https://sumibi.org/cgi-bin/sumibi/stable/sumibi.cgi"
+(defcustom sumibi-server-url "https://sumibi.org/cgi-bin/sumibi/testing/sumibi.cgi"
   "Sumibi$B%5!<%P!<$N(BURL$B$r;XDj$9$k!#(B"
   :type  'string
   :group 'sumibi)
 
-(defcustom sumibi-server-encode 'euc-jp
-  "Sumibi$B%5!<%P!<$H8r49$9$k$H$-$NJ8;z%(%s%3!<%I$r;XDj$9$k!#(B(euc-jp/sjis/utf-8/iso-2022-jp)"
-  :type  'string
-  :group 'sumibi)
-
 (defcustom sumibi-server-cert-data
   "-----BEGIN CERTIFICATE-----
 MIIHPTCCBSWgAwIBAgIBADANBgkqhkiG9w0BAQQFADB5MRAwDgYDVQQKEwdSb290
@@ -251,22 +245,43 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
 ;;
 (defun sumibi-henkan-request (yomi)
   (sumibi-debug-print (format "henkan-input :[%s]\n"  yomi))
+  
+
 
   (message "Requesting to sumibi server...")
-  (let (
-	(result 
-	 (shell-command-to-string
+  (let* (
+	 ;; $B%W%m%;%9MQ%3!<%G%#%s%0%7%9%F%`$N<+F0H=JL(B
+	 (p-encode (symbol-name (car (find-operation-coding-system 'start-process sumibi-curl "xxxx" sumibi-curl))))
+	 (encode 
+	  (cond 
+	   ((string-match "euc-jp" p-encode)
+	    "euc-jp")
+	   ((string-match "shift-jis" p-encode)
+	    "SJIS")
+	   ((string-match "sjis" p-encode)
+	    "SJIS")
+	   ((string-match "iso-2022-jp" p-encode)
+	    "ISO2022JP")
+	   ((string-match "utf-8" p-encode)
+	    "utf8")
+	   (t
+	    p-encode)))
+	 (command 
 	  (concat
 	   sumibi-curl " --silent --show-error "
 	   (format "--connect-timeout %d " sumibi-server-timeout)
 	   sumibi-server-url " "
-	   (format "--data 'string=%s&encode=%S' " yomi sumibi-server-encode)
+	   (format "--data 'string=%s&encode=%s' " yomi encode)
 	   (when sumibi-server-use-cert
 	     (if (not sumibi-server-cert-file)
 		 (error "Error : cert file create miss!")
-	       (format "--cacert '%s' " sumibi-server-cert-file)))
-	   ))))
+	       (format "--cacert '%s' " sumibi-server-cert-file)))))
+	 (result 
+	  (shell-command-to-string
+	   command)))
+
     (sumibi-debug-print (format "henkan-result:%S\n" result))
+    (sumibi-debug-print (format "curl-command :%s\n"  command))
     (if (eq (string-to-char result) ?\( )
 	(progn
 	 (message nil)
@@ -381,7 +396,7 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
        (let ((word (nth (nth cnt sumibi-cand-n) x)))
 	 (sumibi-debug-print (format "word:[%d] %s\n" cnt word))
 	 (setq cnt (+ 1 cnt))
-	 word))
+	 (cadr word)))
      sumibi-henkan-list
      "")))
 
@@ -413,20 +428,20 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
 	      (not (eq (point-at-bol) (point)))
 	      (eq (sumibi-char-charset (preceding-char)) 'ascii)
 	      (and
-	       (< 0 (length (car x)))
-	       (eq (sumibi-char-charset (string-to-char (car x))) 'ascii)))
+	       (< 0 (length (cadar x)))
+	       (eq (sumibi-char-charset (string-to-char (cadar x))) 'ascii)))
 	     (insert " "))
 
 	 (let* (
 		(start       (point-marker))
 		(_n          (nth cnt sumibi-cand-n))
 		(_max        (nth cnt sumibi-cand-max))
-		(insert-word (nth _n x))
+		(insert-word (cadr (nth _n x)))
 		(_     
 		 (if (eq cnt sumibi-cand)
 		     (progn
 		      (insert insert-word)
-		      (message (format "candidate (%d/%d)" (+ _n 1) _max)))
+		      (message (format "[%s] candidate (%d/%d)" insert-word (+ _n 1) _max)))
 		   (insert insert-word)))
 		(end         (point-marker))
 		(ov          (make-overlay start end)))
@@ -472,14 +487,25 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
     (setq i (1+ i))))
 (define-key sumibi-select-mode-map "\C-m"                   'sumibi-select-kakutei)
 (define-key sumibi-select-mode-map "\C-g"                   'sumibi-select-cancel)
+(define-key sumibi-select-mode-map "q"                      'sumibi-select-cancel)
 (define-key sumibi-select-mode-map "\C-b"                   'sumibi-select-prev-word)
 (define-key sumibi-select-mode-map "\C-f"                   'sumibi-select-next-word)
 (define-key sumibi-select-mode-map "\C-a"                   'sumibi-select-first-word)
 (define-key sumibi-select-mode-map "\C-e"                   'sumibi-select-last-word)
-(define-key sumibi-select-mode-map sumibi-rK-trans-key      'sumibi-select-next)
-(define-key sumibi-select-mode-map " "                      'sumibi-select-next)
 (define-key sumibi-select-mode-map "\C-p"                   'sumibi-select-prev)
 (define-key sumibi-select-mode-map "\C-n"                   'sumibi-select-next)
+(define-key sumibi-select-mode-map "b"                      'sumibi-select-prev-word)
+(define-key sumibi-select-mode-map "f"                      'sumibi-select-next-word)
+(define-key sumibi-select-mode-map "a"                      'sumibi-select-first-word)
+(define-key sumibi-select-mode-map "e"                      'sumibi-select-last-word)
+(define-key sumibi-select-mode-map "p"                      'sumibi-select-prev)
+(define-key sumibi-select-mode-map "n"                      'sumibi-select-next)
+(define-key sumibi-select-mode-map sumibi-rK-trans-key      'sumibi-select-next)
+(define-key sumibi-select-mode-map " "                      'sumibi-select-next)
+(define-key sumibi-select-mode-map "j"                      'sumibi-select-kanji)
+(define-key sumibi-select-mode-map "h"                      'sumibi-select-hiragana)
+(define-key sumibi-select-mode-map "k"                      'sumibi-select-katakana)
+(define-key sumibi-select-mode-map "l"                      'sumibi-select-alphabet)
 
 
 ;; $BJQ49$r3NDj$7F~NO$5$l$?%-!<$r:FF~NO$9$k4X?t(B
@@ -572,6 +598,38 @@ omTxJBzcoTWcFbLUvFUufQb1nA5V9FrWk9p2rSVzTMVD
   (sumibi-select-update-display))
 
 
+;; $B;XDj$5$l$?(B type $B$N8uJd$K6/@)E*$K@Z$j$+$($k(B
+(defun sumibi-select-by-type ( _type )
+  (let* (
+	 (n sumibi-cand)
+	 (kouho (nth n sumibi-henkan-list))
+	 (_element (assoc _type kouho)))
+
+    ;; $BO"A[%j%9%H$+$i(B _type $B$G0z$$$?(B index $BHV9f$r@_Dj$9$k$@$1$GNI$$!#(B
+    (when _element
+      (setcar (nthcdr n sumibi-cand-n) (nth 2 _element))
+      (sumibi-select-update-display))))
+
+(defun sumibi-select-kanji ()
+  "$B4A;z8uJd$K6/@)E*$K@Z$j$+$($k(B"
+  (interactive)
+  (sumibi-select-by-type 'j))
+
+(defun sumibi-select-hiragana ()
+  "$B$R$i$,$J8uJd$K6/@)E*$K@Z$j$+$($k(B"
+  (interactive)
+  (sumibi-select-by-type 'h))
+
+(defun sumibi-select-katakana ()
+  "$B%+%?%+%J8uJd$K6/@)E*$K@Z$j$+$($k(B"
+  (interactive)
+  (sumibi-select-by-type 'k))
+
+(defun sumibi-select-alphabet ()
+  "$B%"%k%U%!%Y%C%H8uJd$K6/@)E*$K@Z$j$+$($k(B"
+  (interactive)
+  (sumibi-select-by-type 'l))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; $B%m!<%^;z4A;zJQ494X?t(B
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -781,7 +839,7 @@ point $B$+$i9TF,J}8~$KF1<o$NJ8;zNs$,B3$/4V$r4A;zJQ49$7$^$9!#(B
 (set-language-info "Japanese" 'input-method "japanese-sumibi")
 (setq default-input-method "japanese-sumibi")
 
-(defconst sumibi-version "0.2.0")
+(defconst sumibi-version "0.3.0")
 (defun sumibi-version (&optional arg)
   "$BF~NO%b!<%IJQ99(B"
   (interactive "P")
